@@ -4,9 +4,9 @@
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -15,7 +15,8 @@
  */
 package ghidra.app.plugin.core.debug.gui.stack;
 
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertTrue;
 
 import java.io.IOException;
 import java.util.List;
@@ -25,21 +26,14 @@ import org.junit.*;
 
 import db.Transaction;
 import docking.widgets.table.DynamicTableColumn;
-import ghidra.app.plugin.core.debug.DebuggerCoordinates;
-import ghidra.app.plugin.core.debug.gui.AbstractGhidraHeadedDebuggerGUITest;
+import ghidra.app.plugin.core.debug.gui.AbstractGhidraHeadedDebuggerTest;
 import ghidra.app.plugin.core.debug.gui.model.ObjectTableModel.ValueProperty;
 import ghidra.app.plugin.core.debug.gui.model.ObjectTableModel.ValueRow;
 import ghidra.app.plugin.core.debug.gui.model.QueryPanelTestHelper;
 import ghidra.app.plugin.core.debug.service.modules.DebuggerStaticMappingServicePlugin;
 import ghidra.app.plugin.core.debug.service.modules.DebuggerStaticMappingUtils;
 import ghidra.app.services.DebuggerStaticMappingService;
-import ghidra.dbg.target.TargetMemoryRegion;
-import ghidra.dbg.target.TargetStackFrame;
-import ghidra.dbg.target.schema.SchemaContext;
-import ghidra.dbg.target.schema.TargetObjectSchema.SchemaName;
-import ghidra.dbg.target.schema.XmlSchemaContext;
-import ghidra.dbg.util.PathPattern;
-import ghidra.dbg.util.PathUtils;
+import ghidra.debug.api.tracemgr.DebuggerCoordinates;
 import ghidra.program.model.address.Address;
 import ghidra.program.model.address.AddressSet;
 import ghidra.program.model.lang.Register;
@@ -49,16 +43,73 @@ import ghidra.program.util.ProgramLocation;
 import ghidra.trace.model.*;
 import ghidra.trace.model.memory.TraceObjectMemoryRegion;
 import ghidra.trace.model.stack.TraceObjectStack;
-import ghidra.trace.model.target.*;
+import ghidra.trace.model.stack.TraceObjectStackFrame;
+import ghidra.trace.model.target.TraceObject;
 import ghidra.trace.model.target.TraceObject.ConflictResolution;
+import ghidra.trace.model.target.TraceObjectManager;
+import ghidra.trace.model.target.path.*;
+import ghidra.trace.model.target.schema.SchemaContext;
+import ghidra.trace.model.target.schema.TraceObjectSchema.SchemaName;
+import ghidra.trace.model.target.schema.XmlSchemaContext;
 import ghidra.trace.model.thread.TraceObjectThread;
+import ghidra.util.table.GhidraTable;
 import ghidra.util.task.TaskMonitor;
 
 /**
  * NOTE: I no longer synthesize a stack frame when the stack is absent. It's a bit of a hack, and I
  * don't know if it's really valuable. In fact, in might obscure the fact that the stack is absent.
  */
-public class DebuggerStackProviderTest extends AbstractGhidraHeadedDebuggerGUITest {
+public class DebuggerStackProviderTest extends AbstractGhidraHeadedDebuggerTest {
+	public static final String CTX_XML = """
+			<context>
+			    <schema name='Session' elementResync='NEVER' attributeResync='ONCE'>
+			        <attribute name='Processes' schema='ProcessContainer' />
+			    </schema>
+			    <schema name='ProcessContainer' canonical='yes' elementResync='NEVER'
+			            attributeResync='ONCE'>
+			        <element schema='Process' />
+			    </schema>
+			    <schema name='Process' elementResync='NEVER' attributeResync='ONCE'>
+			        <attribute name='Threads' schema='ThreadContainer' />
+			        <attribute name='Memory' schema='RegionContainer' />
+			    </schema>
+			    <schema name='ThreadContainer' canonical='yes' elementResync='NEVER'
+			            attributeResync='ONCE'>
+			        <element schema='Thread' />
+			    </schema>
+			    <schema name='Thread' elementResync='NEVER' attributeResync='NEVER'>
+			        <interface name='Thread' />
+			        <interface name='Aggregate' />
+			        <attribute name='Stack' schema='Stack' />
+			        <attribute name='Registers' schema='RegisterContainer' />
+			    </schema>
+			    <schema name='Stack' canonical='yes' elementResync='NEVER'
+			            attributeResync='ONCE'>
+			        <interface name='Stack' />
+			        <element schema='Frame' />
+			    </schema>
+			    <schema name='Frame' elementResync='NEVER' attributeResync='NEVER'>
+			        <interface name='StackFrame' />
+			        <interface name='Activatable' />
+			    </schema>
+			    <schema name='RegisterContainer' canonical='yes' elementResync='NEVER'
+			            attributeResync='NEVER'>
+			        <interface name='RegisterContainer' />
+			        <element schema='Register' />
+			    </schema>
+			    <schema name='Register' elementResync='NEVER' attributeResync='NEVER'>
+			        <interface name='Register' />
+			    </schema>
+			    <schema name='RegionContainer' canonical='yes' elementResync='NEVER'
+			            attributeResync='ONCE'>
+			        <element schema='Region' />
+			    </schema>
+			    <schema name='Region' elementResync='NEVER' attributeResync='NEVER'>
+			        <interface name='MemoryRegion' />
+			    </schema>
+			</context>
+			""";
+
 	protected DebuggerStackPlugin stackPlugin;
 	protected DebuggerStackProvider stackProvider;
 	protected DebuggerStaticMappingService mappingService;
@@ -109,54 +160,7 @@ public class DebuggerStackProviderTest extends AbstractGhidraHeadedDebuggerGUITe
 
 	public void activateObjectsMode() throws Exception {
 		// NOTE the use of index='1' allowing object-based managers to ID unique path
-		ctx = XmlSchemaContext.deserialize("""
-				<context>
-				    <schema name='Session' elementResync='NEVER' attributeResync='ONCE'>
-				        <attribute name='Processes' schema='ProcessContainer' />
-				    </schema>
-				    <schema name='ProcessContainer' canonical='yes' elementResync='NEVER'
-				            attributeResync='ONCE'>
-				        <element schema='Process' />
-				    </schema>
-				    <schema name='Process' elementResync='NEVER' attributeResync='ONCE'>
-				        <attribute name='Threads' schema='ThreadContainer' />
-				        <attribute name='Memory' schema='RegionContainer' />
-				    </schema>
-				    <schema name='ThreadContainer' canonical='yes' elementResync='NEVER'
-				            attributeResync='ONCE'>
-				        <element schema='Thread' />
-				    </schema>
-				    <schema name='Thread' elementResync='NEVER' attributeResync='NEVER'>
-				        <interface name='Thread' />
-				        <interface name='Aggregate' />
-				        <attribute name='Stack' schema='Stack' />
-				        <attribute name='Registers' schema='RegisterContainer' />
-				    </schema>
-				    <schema name='Stack' canonical='yes' elementResync='NEVER'
-				            attributeResync='ONCE'>
-				        <interface name='Stack' />
-				        <element schema='Frame' />
-				    </schema>
-				    <schema name='Frame' elementResync='NEVER' attributeResync='NEVER'>
-				        <interface name='StackFrame' />
-				    </schema>
-				    <schema name='RegisterContainer' canonical='yes' elementResync='NEVER'
-				            attributeResync='NEVER'>
-				        <interface name='RegisterContainer' />
-				        <element schema='Register' />
-				    </schema>
-				    <schema name='Register' elementResync='NEVER' attributeResync='NEVER'>
-				        <interface name='Register' />
-				    </schema>
-				    <schema name='RegionContainer' canonical='yes' elementResync='NEVER'
-				            attributeResync='ONCE'>
-				        <element schema='Region' />
-				    </schema>
-				    <schema name='Region' elementResync='NEVER' attributeResync='NEVER'>
-				        <interface name='MemoryRegion' />
-				    </schema>
-				</context>
-				""");
+		ctx = XmlSchemaContext.deserialize(CTX_XML);
 
 		try (Transaction tx = tb.startTransaction()) {
 			tb.trace.getObjectManager().createRootObject(ctx.getSchema(new SchemaName("Session")));
@@ -164,9 +168,8 @@ public class DebuggerStackProviderTest extends AbstractGhidraHeadedDebuggerGUITe
 	}
 
 	protected TraceObjectThread addThread(int n) {
-		PathPattern threadPattern = new PathPattern(PathUtils.parse("Processes[1].Threads[]"));
-		TraceObjectKeyPath threadPath =
-			TraceObjectKeyPath.of(threadPattern.applyIntKeys(n).getSingletonPath());
+		PathPattern threadPattern = PathFilter.parse("Processes[1].Threads[]");
+		KeyPath threadPath = threadPattern.applyIntKeys(n).getSingletonPath();
 		try (Transaction tx = tb.startTransaction()) {
 			return Objects.requireNonNull(tb.trace.getObjectManager()
 					.createObject(threadPath)
@@ -177,7 +180,7 @@ public class DebuggerStackProviderTest extends AbstractGhidraHeadedDebuggerGUITe
 	}
 
 	protected TraceObjectStack addStack(TraceObjectThread thread) {
-		TraceObjectKeyPath stackPath = thread.getObject().getCanonicalPath().extend("Stack");
+		KeyPath stackPath = thread.getObject().getCanonicalPath().extend("Stack");
 		try (Transaction tx = tb.startTransaction()) {
 			return Objects.requireNonNull(tb.trace.getObjectManager()
 					.createObject(stackPath)
@@ -192,14 +195,14 @@ public class DebuggerStackProviderTest extends AbstractGhidraHeadedDebuggerGUITe
 	}
 
 	protected void addStackFrames(TraceObjectStack stack, int count) {
-		TraceObjectKeyPath stackPath = stack.getObject().getCanonicalPath();
+		KeyPath stackPath = stack.getObject().getCanonicalPath();
 		TraceObjectManager om = tb.trace.getObjectManager();
 		try (Transaction tx = tb.startTransaction()) {
 			for (int i = 0; i < count; i++) {
 				TraceObject frame = om.createObject(stackPath.index(i))
 						.insert(Lifespan.nowOn(0), ConflictResolution.TRUNCATE)
 						.getDestination(null);
-				frame.setAttribute(Lifespan.nowOn(0), TargetStackFrame.PC_ATTRIBUTE_NAME,
+				frame.setAttribute(Lifespan.nowOn(0), TraceObjectStackFrame.KEY_PC,
 					tb.addr(0x00400100 + 0x100 * i));
 			}
 		}
@@ -215,15 +218,20 @@ public class DebuggerStackProviderTest extends AbstractGhidraHeadedDebuggerGUITe
 
 	protected void assertRow(int level, Address pcVal, Function func) {
 		ValueRow row = stackProvider.panel.getAllItems().get(level);
+		var tableModel = QueryPanelTestHelper.getTableModel(stackProvider.panel);
+		GhidraTable table = QueryPanelTestHelper.getTable(stackProvider.panel);
 
-		DynamicTableColumn<ValueRow, String, Trace> levelCol =
-			stackProvider.panel.getColumnByNameAndType("Level", String.class).getValue();
-		DynamicTableColumn<ValueRow, ?, Trace> pcCol =
-			stackProvider.panel.getColumnByNameAndType("PC", ValueProperty.class).getValue();
-		DynamicTableColumn<ValueRow, Function, Trace> funcCol =
-			stackProvider.panel.getColumnByNameAndType("Function", Function.class).getValue();
+		DynamicTableColumn<ValueRow, String, Trace> levelCol = QueryPanelTestHelper
+				.getColumnByNameAndType(tableModel, table, "Level", String.class)
+				.column();
+		DynamicTableColumn<ValueRow, ?, Trace> pcCol = QueryPanelTestHelper
+				.getColumnByNameAndType(tableModel, table, "PC", ValueProperty.class)
+				.column();
+		DynamicTableColumn<ValueRow, ?, Trace> funcCol = QueryPanelTestHelper
+				.getColumnByNameAndType(tableModel, table, "Function", ValueProperty.class)
+				.column();
 
-		assertEquals(PathUtils.makeKey(PathUtils.makeIndex(level)), rowColVal(row, levelCol));
+		assertEquals(KeyPath.makeKey(KeyPath.makeIndex(level)), rowColVal(row, levelCol));
 		assertEquals(pcVal, rowColVal(row, pcCol));
 		assertEquals(func, rowColVal(row, funcCol));
 	}
@@ -308,8 +316,6 @@ public class DebuggerStackProviderTest extends AbstractGhidraHeadedDebuggerGUITe
 
 	/**
 	 * Because keys are strings, we need to ensure they get sorted numerically
-	 * 
-	 * @throws Exception
 	 */
 	@Test
 	public void testTableSortedCorrectly() throws Exception {
@@ -326,7 +332,7 @@ public class DebuggerStackProviderTest extends AbstractGhidraHeadedDebuggerGUITe
 			assertTableSize(15);
 			List<ValueRow> allItems = stackProvider.panel.getAllItems();
 			for (int i = 0; i < 15; i++) {
-				assertEquals(PathUtils.makeKey(PathUtils.makeIndex(i)), allItems.get(i).getKey());
+				assertEquals(KeyPath.makeKey(KeyPath.makeIndex(i)), allItems.get(i).getKey());
 			}
 		});
 	}
@@ -350,7 +356,7 @@ public class DebuggerStackProviderTest extends AbstractGhidraHeadedDebuggerGUITe
 					.createObject(stack.getObject().getCanonicalPath().index(2))
 					.insert(Lifespan.nowOn(0), ConflictResolution.TRUNCATE)
 					.getDestination(null);
-			frame2.setAttribute(Lifespan.nowOn(0), TargetStackFrame.PC_ATTRIBUTE_NAME,
+			frame2.setAttribute(Lifespan.nowOn(0), TraceObjectStackFrame.KEY_PC,
 				tb.addr(0x00400300));
 		}
 		waitForDomainObject(tb.trace);
@@ -575,12 +581,12 @@ public class DebuggerStackProviderTest extends AbstractGhidraHeadedDebuggerGUITe
 
 		try (Transaction tx = tb.startTransaction()) {
 			TraceObjectMemoryRegion region = Objects.requireNonNull(tb.trace.getObjectManager()
-					.createObject(TraceObjectKeyPath.parse("Processes[1].Memory[bin:.text]"))
+					.createObject(KeyPath.parse("Processes[1].Memory[bin:.text]"))
 					.insert(Lifespan.nowOn(0), ConflictResolution.TRUNCATE)
 					.getDestination(null)
 					.queryInterface(TraceObjectMemoryRegion.class));
 			region.getObject()
-					.setAttribute(Lifespan.nowOn(0), TargetMemoryRegion.RANGE_ATTRIBUTE_NAME,
+					.setAttribute(Lifespan.nowOn(0), TraceObjectMemoryRegion.KEY_RANGE,
 						tb.drng(0x00400000, 0x00400fff));
 
 			TraceLocation dloc =
