@@ -4,9 +4,9 @@
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -19,6 +19,7 @@ import static org.junit.Assert.*;
 
 import org.junit.*;
 
+import db.Transaction;
 import ghidra.app.plugin.core.bookmark.BookmarkPlugin;
 import ghidra.app.plugin.core.clear.ClearPlugin;
 import ghidra.app.plugin.core.codebrowser.CodeBrowserPlugin;
@@ -782,13 +783,12 @@ public class CodeUnitIteratorTest extends AbstractGhidraHeadedIntegrationTest {
 	@Test
 	public void testIteratorForComments() throws Exception {
 		startTransaction();
-		mem.createInitializedBlock("test", addr(0), 100, (byte) 0, TaskMonitor.DUMMY,
-			false);
+		mem.createInitializedBlock("test", addr(0), 100, (byte) 0, TaskMonitor.DUMMY, false);
 
 		for (int i = 0; i < 20; i++) {
 			CodeUnit cu = listing.getCodeUnitAt(addr(i + 10));
-			cu.setComment(CodeUnit.PLATE_COMMENT, "comment for plate " + i);
-			assertEquals("comment for plate " + i, cu.getComment(CodeUnit.PLATE_COMMENT));
+			cu.setComment(CommentType.PLATE, "comment for plate " + i);
+			assertEquals("comment for plate " + i, cu.getComment(CommentType.PLATE));
 		}
 		endTransaction();
 
@@ -801,8 +801,8 @@ public class CodeUnitIteratorTest extends AbstractGhidraHeadedIntegrationTest {
 			CodeUnit cu = iter.next();
 			expectedAddr = addr(n + 10);
 			assertEquals(expectedAddr, cu.getMinAddress());
-			assertNotNull(cu.getComment(CodeUnit.PLATE_COMMENT));
-			assertNull(cu.getComment(CodeUnit.EOL_COMMENT));
+			assertNotNull(cu.getComment(CommentType.PLATE));
+			assertNull(cu.getComment(CommentType.EOL));
 			++n;
 		}
 	}
@@ -810,26 +810,24 @@ public class CodeUnitIteratorTest extends AbstractGhidraHeadedIntegrationTest {
 	@Test
 	public void testIteratorForCommentType() throws Exception {
 		startTransaction();
-		mem.createInitializedBlock("test", addr(0), 100, (byte) 0, TaskMonitor.DUMMY,
-			false);
-		mem.createInitializedBlock("test2", addr(5000), 100, (byte) 0,
-			TaskMonitor.DUMMY, false);
+		mem.createInitializedBlock("test", addr(0), 100, (byte) 0, TaskMonitor.DUMMY, false);
+		mem.createInitializedBlock("test2", addr(5000), 100, (byte) 0, TaskMonitor.DUMMY, false);
 
 		for (int i = 0; i < 20; i++) {
 			CodeUnit cu = listing.getCodeUnitAt(addr(i + 10));
-			cu.setComment(CodeUnit.PLATE_COMMENT, "comment for plate " + i);
-			cu.setComment(CodeUnit.EOL_COMMENT, "comment for eol " + i);
+			cu.setComment(CommentType.PLATE, "comment for plate " + i);
+			cu.setComment(CommentType.EOL, "comment for eol " + i);
 		}
 
 		for (int i = 20; i < 30; i++) {
 			CodeUnit cu = listing.getCodeUnitAt(addr(i + 5000));
-			cu.setComment(CodeUnit.PLATE_COMMENT, "comment for plate " + i);
-			cu.setComment(CodeUnit.EOL_COMMENT, "comment for eol " + i);
+			cu.setComment(CommentType.PLATE, "comment for plate " + i);
+			cu.setComment(CommentType.EOL, "comment for eol " + i);
 		}
 		endTransaction();
 
-		CodeUnitIterator iter = ((ProgramDB) program).getCodeManager().getCommentCodeUnitIterator(
-			CodeUnit.PLATE_COMMENT, mem);
+		CodeUnitIterator iter = ((ProgramDB) program).getCodeManager()
+				.getCommentCodeUnitIterator(CommentType.PLATE, mem);
 		int n = 0;
 		Address expectedAddr = null;
 		while (iter.hasNext()) {
@@ -850,20 +848,19 @@ public class CodeUnitIteratorTest extends AbstractGhidraHeadedIntegrationTest {
 	@Test
 	public void testIteratorForCommentsBackwards() throws Exception {
 		startTransaction();
-		mem.createInitializedBlock("test", addr(0), 100, (byte) 0, TaskMonitor.DUMMY,
-			false);
+		mem.createInitializedBlock("test", addr(0), 100, (byte) 0, TaskMonitor.DUMMY, false);
 
 		CodeUnit cu = listing.getCodeUnitAt(addr(90));
-		cu.setComment(CodeUnit.PLATE_COMMENT, "comment for plate " + addr(90));
+		cu.setComment(CommentType.PLATE, "comment for plate " + addr(90));
 
 		cu = listing.getCodeUnitAt(addr(80));
-		cu.setComment(CodeUnit.PLATE_COMMENT, "comment for plate " + addr(80));
+		cu.setComment(CommentType.PLATE, "comment for plate " + addr(80));
 
 		cu = listing.getCodeUnitAt(addr(70));
-		cu.setComment(CodeUnit.PLATE_COMMENT, "comment for plate " + addr(70));
+		cu.setComment(CommentType.PLATE, "comment for plate " + addr(70));
 
 		cu = listing.getCodeUnitAt(addr(10));
-		cu.setComment(CodeUnit.PLATE_COMMENT, "comment for plate " + addr(10));
+		cu.setComment(CommentType.PLATE, "comment for plate " + addr(10));
 
 		endTransaction();
 		CodeUnitIterator iter =
@@ -891,8 +888,7 @@ public class CodeUnitIteratorTest extends AbstractGhidraHeadedIntegrationTest {
 	@Test
 	public void testGetPropertyCodeUnitIterator() throws Exception {
 		startTransaction();
-		mem.createInitializedBlock("test", addr(0), 100, (byte) 0, TaskMonitor.DUMMY,
-			false);
+		mem.createInitializedBlock("test", addr(0), 100, (byte) 0, TaskMonitor.DUMMY, false);
 		for (int i = 0; i < 20; i++) {
 			CodeUnit cu = listing.getCodeUnitAt(addr(i + 10));
 			cu.setProperty("Numbers", i);
@@ -914,8 +910,7 @@ public class CodeUnitIteratorTest extends AbstractGhidraHeadedIntegrationTest {
 	@Test
 	public void testGetPropertyCuIteratorBackwards() throws Exception {
 		startTransaction();
-		mem.createInitializedBlock("test", addr(0), 100, (byte) 0, TaskMonitor.DUMMY,
-			false);
+		mem.createInitializedBlock("test", addr(0), 100, (byte) 0, TaskMonitor.DUMMY, false);
 		for (int i = 0; i < 20; i++) {
 			CodeUnit cu = listing.getCodeUnitAt(addr(i));
 			cu.setProperty("Numbers", i);
@@ -936,8 +931,7 @@ public class CodeUnitIteratorTest extends AbstractGhidraHeadedIntegrationTest {
 	@Test
 	public void testGetPropertCUIteratorSet() throws Exception {
 		startTransaction();
-		mem.createInitializedBlock("bk1", addr(0), 200, (byte) 0, TaskMonitor.DUMMY,
-			false);
+		mem.createInitializedBlock("bk1", addr(0), 200, (byte) 0, TaskMonitor.DUMMY, false);
 		// addresses 10-19
 		for (int i = 0; i < 20; i++) {
 			CodeUnit cu = listing.getCodeUnitAt(addr(i + 10));
@@ -972,16 +966,15 @@ public class CodeUnitIteratorTest extends AbstractGhidraHeadedIntegrationTest {
 	public void testPropertyCommentIterator() throws Exception {
 		startTransaction();
 // 		mem.createUninitializedBlock("Test", addr(0), 200);
-		mem.createInitializedBlock("bk1", addr(0), 200, (byte) 0, TaskMonitor.DUMMY,
-			false);
+		mem.createInitializedBlock("bk1", addr(0), 200, (byte) 0, TaskMonitor.DUMMY, false);
 		for (int i = 0; i < 20; i++) {
 			CodeUnit cu = listing.getCodeUnitAt(addr(i + 10));
-			cu.setComment(CodeUnit.EOL_COMMENT, "This is an eol comment " + i);
-			assertNotNull(cu.getComment(CodeUnit.EOL_COMMENT));
+			cu.setComment(CommentType.EOL, "This is an eol comment " + i);
+			assertNotNull(cu.getComment(CommentType.EOL));
 		}
 		for (int i = 100; i < 120; i++) {
 			CodeUnit cu = listing.getCodeUnitAt(addr(i));
-			cu.setComment(CodeUnit.PRE_COMMENT, "This is pre comment " + i);
+			cu.setComment(CommentType.PRE, "This is pre comment " + i);
 		}
 		endTransaction();
 		AddressSet set = new AddressSet(addr(0), addr(5));
@@ -1195,8 +1188,7 @@ public class CodeUnitIteratorTest extends AbstractGhidraHeadedIntegrationTest {
 	@Test
 	public void testGetDataBackwards() throws Exception {
 		startTransaction();
-		mem.createInitializedBlock("test", addr(0), 1000, (byte) 0,
-			TaskMonitor.DUMMY, false);
+		mem.createInitializedBlock("test", addr(0), 1000, (byte) 0, TaskMonitor.DUMMY, false);
 
 		for (int i = 0; i < 10; i++) {
 			listing.createData(addr(i), DataType.DEFAULT, 1);
@@ -1250,8 +1242,7 @@ public class CodeUnitIteratorTest extends AbstractGhidraHeadedIntegrationTest {
 	@Test
 	public void testGetCompositeData() throws Exception {
 		startTransaction();
-		mem.createInitializedBlock("test", addr(0), 1000, (byte) 0,
-			TaskMonitor.DUMMY, false);
+		mem.createInitializedBlock("test", addr(0), 1000, (byte) 0, TaskMonitor.DUMMY, false);
 
 		Structure struct = new StructureDataType("struct_1", 100);
 		Structure struct2 = new StructureDataType("struct_2", 0);
@@ -1305,8 +1296,7 @@ public class CodeUnitIteratorTest extends AbstractGhidraHeadedIntegrationTest {
 	@Test
 	public void testGetCompositeDataStartingAt() throws Exception {
 		startTransaction();
-		mem.createInitializedBlock("test", addr(0), 1000, (byte) 0,
-			TaskMonitor.DUMMY, false);
+		mem.createInitializedBlock("test", addr(0), 1000, (byte) 0, TaskMonitor.DUMMY, false);
 
 		Structure struct = new StructureDataType("struct_1", 100);
 		Structure struct2 = new StructureDataType("struct_2", 0);
@@ -1359,8 +1349,7 @@ public class CodeUnitIteratorTest extends AbstractGhidraHeadedIntegrationTest {
 	@Test
 	public void testGetCompositeDataInSet() throws Exception {
 		startTransaction();
-		mem.createInitializedBlock("test", addr(0), 1000, (byte) 0,
-			TaskMonitor.DUMMY, false);
+		mem.createInitializedBlock("test", addr(0), 1000, (byte) 0, TaskMonitor.DUMMY, false);
 
 		Structure struct = new StructureDataType("struct_1", 100);
 		Structure struct2 = new StructureDataType("struct_2", 0);
@@ -1417,8 +1406,7 @@ public class CodeUnitIteratorTest extends AbstractGhidraHeadedIntegrationTest {
 	public void testGetDefinedDataIterator() throws Exception {
 		startTransaction();
 		mem.removeBlock(mem.getBlock(addr(1000)), monitor);
-		mem.createInitializedBlock("test", addr(0), 1000, (byte) 0,
-			TaskMonitor.DUMMY, false);
+		mem.createInitializedBlock("test", addr(0), 1000, (byte) 0, TaskMonitor.DUMMY, false);
 
 		for (int i = 0; i < 10; i++) {
 			listing.createData(addr(i), new ByteDataType(), 1);
@@ -1490,8 +1478,7 @@ public class CodeUnitIteratorTest extends AbstractGhidraHeadedIntegrationTest {
 	public void testGetDefinedDataAtIterator() throws Exception {
 		startTransaction();
 		mem.removeBlock(mem.getBlock(addr(1000)), monitor);
-		mem.createInitializedBlock("test", addr(0), 1000, (byte) 0,
-			TaskMonitor.DUMMY, false);
+		mem.createInitializedBlock("test", addr(0), 1000, (byte) 0, TaskMonitor.DUMMY, false);
 
 		for (int i = 0; i < 10; i++) {
 			listing.createData(addr(i), DataType.DEFAULT, 1);
@@ -1552,8 +1539,7 @@ public class CodeUnitIteratorTest extends AbstractGhidraHeadedIntegrationTest {
 	@Test
 	public void testGetDefinedDataSetIterator() throws Exception {
 		startTransaction();
-		mem.createInitializedBlock("test", addr(0), 1000, (byte) 0,
-			TaskMonitor.DUMMY, false);
+		mem.createInitializedBlock("test", addr(0), 1000, (byte) 0, TaskMonitor.DUMMY, false);
 
 		for (int i = 0; i < 10; i++) {
 			listing.createData(addr(i), new ByteDataType(), 0);
@@ -1678,6 +1664,59 @@ public class CodeUnitIteratorTest extends AbstractGhidraHeadedIntegrationTest {
 		assertEquals(10, cnt);
 	}
 
+	@Test
+	public void testGetCodeUnitsSetWithOverride() throws Exception {
+
+		// set length-override on 0x3f4
+		try (Transaction tx = program.openTransaction("Set Length Override")) {
+			program.getListing().getInstructionAt(addr(0x3f4)).setLengthOverride(1);
+		}
+
+		AddressSet set = new AddressSet();
+		set.addRange(addr(0x3f0), addr(0x3f9));
+
+		CodeUnitIterator it = listing.getCodeUnits(set, true);
+
+		CodeUnit cu = it.next();
+		assertEquals(addr(0x3f1), cu.getMinAddress());
+		assertTrue(cu instanceof Data);
+		assertFalse(((Data) cu).isDefined());
+
+		cu = it.next();
+		assertEquals(addr(0x3f2), cu.getMinAddress());
+		assertTrue(cu instanceof Instruction);
+		assertEquals(2, cu.getLength());
+
+		cu = it.next();
+		assertEquals(addr(0x3f4), cu.getMinAddress());
+		assertTrue(cu instanceof Instruction);
+		assertEquals(1, cu.getLength()); // length overriden
+		assertEquals("imm r0,#0x0", cu.toString());
+
+		cu = it.next();
+		assertEquals(addr(0x3f5), cu.getMinAddress());
+		assertTrue(cu instanceof Data);
+		assertFalse(((Data) cu).isDefined());
+
+		cu = it.next();
+		assertEquals(addr(0x3f6), cu.getMinAddress());
+		assertTrue(cu instanceof Instruction);
+		assertEquals(2, cu.getLength());
+
+		cu = it.next();
+		assertEquals(addr(0x3f8), cu.getMinAddress());
+		assertTrue(cu instanceof Data);
+		assertFalse(((Data) cu).isDefined());
+
+		cu = it.next();
+		assertEquals(addr(0x3f9), cu.getMinAddress());
+		assertTrue(cu instanceof Data);
+		assertFalse(((Data) cu).isDefined());
+
+		assertFalse(it.hasNext());
+		assertNull(it.next());
+	}
+
 	private Address addr(long l) {
 		return space.getAddress(l);
 	}
@@ -1704,7 +1743,7 @@ public class CodeUnitIteratorTest extends AbstractGhidraHeadedIntegrationTest {
 		ProcessorContext context = new ProgramProcessorContext(program.getProgramContext(), atAddr);
 		InstructionPrototype proto = program.getLanguage().parse(buf, context, false);
 
-		listing.createInstruction(atAddr, proto, buf, context);
+		listing.createInstruction(atAddr, proto, buf, context, 0);
 	}
 
 	private void startTransaction() {
