@@ -4,9 +4,9 @@
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -809,12 +809,13 @@ public class VTSessionDB extends DomainObjectAdapterDB implements VTSession {
 	}
 
 	@Override
-	public void endTransaction(int transactionID, boolean commit) {
+	public boolean endTransaction(int transactionID, boolean commit) {
 		TransactionInfo transaction = getCurrentTransactionInfo();
-		super.endTransaction(transactionID, commit);
+		boolean committed = super.endTransaction(transactionID, commit);
 		if (changeSetsModified && transaction.getStatus() == Status.COMMITTED) {
 			changeSetsModified = false;
 		}
+		return committed;
 	}
 
 	@Override
