@@ -4,9 +4,9 @@
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -23,9 +23,13 @@ import generic.jar.ResourceFile;
 import ghidra.util.*;
 import ghidra.util.datastruct.LRUMap;
 import ghidra.util.exception.AssertException;
+import ghidra.util.exception.CancelledException;
 import ghidra.util.task.TaskMonitor;
+import util.CollectionUtils;
+import utilities.util.FileUtilities;
 import utilities.util.reflection.ReflectionUtilities;
 import utility.application.ApplicationLayout;
+import utility.application.ApplicationUtilities;
 import utility.module.ModuleUtilities;
 
 /**
@@ -40,7 +44,7 @@ import utility.module.ModuleUtilities;
  * <pre>
  *   ApplicationLayout layout = new GhidraApplicationLayout();
  *   ApplicationConfiguration configuration = new GhidraApplicationConfiguration();
- *   Application.initalizeApplication(layout, configuration);
+ *   Application.initializeApplication(layout, configuration);
  * </pre>
  */
 public class Application {
@@ -70,14 +74,6 @@ public class Application {
 
 	private void initialize() {
 
-		// Create application's user directories
-		try {
-			layout.createUserDirs();
-		}
-		catch (IOException e) {
-			throw new AssertException(e.getMessage());
-		}
-
 		// Set headless property
 		String isHeadless = Boolean.toString(configuration.isHeadless());
 		System.setProperty(SystemUtilities.HEADLESS_PROPERTY, isHeadless);
@@ -212,6 +208,10 @@ public class Application {
 		return app.getModuleForClass(className);
 	}
 
+	public static ResourceFile getModuleContainingClass(Class<?> c) {
+		return app.getModuleForClass(c);
+	}
+
 	private void findJavaSourceDirectories(List<ResourceFile> list,
 			ResourceFile moduleRootDirectory) {
 		ResourceFile srcDir = new ResourceFile(moduleRootDirectory, "src");
@@ -251,6 +251,18 @@ public class Application {
 	}
 
 	private ResourceFile getModuleForClass(String className) {
+		try {
+			Class<?> callersClass = Class.forName(className);
+			return getModuleForClass(callersClass);
+		}
+		catch (ClassNotFoundException e) {
+			// This can happen when we are being called from a script, which is not in the
+			// classpath.  This file will not have a module anyway.
+			return null;
+		}
+	}
+
+	private String toPath(String className) {
 		// get rid of nested class name(s) if present
 		int dollar = className.indexOf('$');
 		if (dollar != -1) {
@@ -258,27 +270,22 @@ public class Application {
 		}
 
 		String path = className.replace('.', '/');
-		String sourcePath = path + ".java";
-		String classFilePath = path + ".class";
+		return path + ".class";
+	}
+
+	private ResourceFile getModuleForClass(Class<?> clazz) {
 
 		if (inSingleJarMode()) {
+			String classFilePath = toPath(clazz.getName());
 			GModule gModule = getModuleFromTreeMap(classFilePath);
 			return gModule == null ? null : gModule.getModuleRoot();
 		}
 
 		// we're running from a binary installation...so get our jar and go up one
-		Class<?> callersClass;
-		try {
-			callersClass = Class.forName(className);
-		}
-		catch (ClassNotFoundException e) {
-			// This can happen when we are being called from a script, which is not in the
-			// classpath.  This file will not have a module anyway
-			return null;
-		}
-
-		File sourceLocationForClass = SystemUtilities.getSourceLocationForClass(callersClass);
+		File sourceLocationForClass = SystemUtilities.getSourceLocationForClass(clazz);
 		if (sourceLocationForClass.isDirectory()) {
+			String classFilePath = toPath(clazz.getName());
+			String sourcePath = classFilePath.replace(".class", ".java");
 			return findModuleForJavaSource(sourcePath);
 		}
 
@@ -467,13 +474,13 @@ public class Application {
 				exactFilename);
 		}
 
-		// Allow win_x86_32 to be used for win_x86_64 as fallback
-		if (file == null && Platform.CURRENT_PLATFORM == Platform.WIN_X86_64) {
-			file = getModuleFile(module, "build/os/" + Platform.WIN_X86_32.getDirectoryName(),
+		// Allow win_x86_64 to be used for win_arm_64 as fallback (requires Windows emulation)
+		if (file == null && Platform.CURRENT_PLATFORM == Platform.WIN_ARM_64) {
+			file = getModuleFile(module, "build/os/" + Platform.WIN_X86_64.getDirectoryName(),
 				exactFilename);
 		}
-		if (file == null && Platform.CURRENT_PLATFORM == Platform.WIN_X86_64) {
-			file = getModuleFile(module, "os/" + Platform.WIN_X86_32.getDirectoryName(),
+		if (file == null && Platform.CURRENT_PLATFORM == Platform.WIN_ARM_64) {
+			file = getModuleFile(module, "os/" + Platform.WIN_X86_64.getDirectoryName(),
 				exactFilename);
 		}
 
@@ -513,12 +520,12 @@ public class Application {
 			file = findModuleFile("os/" + Platform.CURRENT_PLATFORM.getDirectoryName(), path);
 		}
 
-		// Allow win_x86_32 to be used for win_x86_64 as fallback
-		if (file == null && Platform.CURRENT_PLATFORM == Platform.WIN_X86_64) {
-			file = findModuleFile("build/os/" + Platform.WIN_X86_32.getDirectoryName(), path);
+		// Allow win_x86_64 to be used for win_arm_64 as fallback (requires Windows emulation)
+		if (file == null && Platform.CURRENT_PLATFORM == Platform.WIN_ARM_64) {
+			file = findModuleFile("build/os/" + Platform.WIN_X86_64.getDirectoryName(), path);
 		}
-		if (file == null && Platform.CURRENT_PLATFORM == Platform.WIN_X86_64) {
-			file = findModuleFile("os/" + Platform.WIN_X86_32.getDirectoryName(), path);
+		if (file == null && Platform.CURRENT_PLATFORM == Platform.WIN_ARM_64) {
+			file = findModuleFile("os/" + Platform.WIN_X86_64.getDirectoryName(), path);
 		}
 
 		// Allow mac_x86_64 to be used for mac_arm_64 as fallback (requires macOS Rosetta 2)
@@ -618,9 +625,41 @@ public class Application {
 		return app.layout.getUserSettingsDir();
 	}
 
+	/**
+	 * Returns a list of files in a setting subdirectory that have the given file extension,
+	 * copying files from older versions of Ghidra if the settings dir is not yet established.
+	 * @param dirName the name of the settings subdirectory.
+	 * @param fileExtension the file name suffix
+	 * @return a list of files in a setting sub directory that have the given file extension
+	 */
+	public static List<File> getUserSettingsFiles(String dirName, String fileExtension) {
+		File userSettingsDir = getUserSettingsDirectory();
+		File subSettingsDir = new File(userSettingsDir, dirName);
+		FileFilter filter = f -> f.getName().endsWith(fileExtension);
+
+		if (!subSettingsDir.exists()) {
+			subSettingsDir.mkdir();
+			copyFilesFromPreviousVersion(subSettingsDir, dirName, filter);
+		}
+		File[] files = subSettingsDir.listFiles(filter);
+		return CollectionUtils.asList(files);
+	}
+
+	private static void copyFilesFromPreviousVersion(File subSettingsDir, String dirName,
+			FileFilter filter) {
+		File previousDir = GenericRunInfo.getPreviousApplicationSettingsDir(dirName, filter);
+		if (previousDir != null) {
+			try {
+				FileUtilities.copyDir(previousDir, subSettingsDir, filter, TaskMonitor.DUMMY);
+			}
+			catch (CancelledException | IOException e) {
+				// don't care - just means we couldn't copy old files to new ghidra version
+			}
+		}
+	}
+
 	/**
 	 * Returns the temporary directory specific to the user and the application.
-	 * Directory has name of &lt;username&gt;-&lt;appname&gt;
 	 * This directory may be removed at system reboot or during periodic
 	 * system cleanup of unused temp files.
 	 * This directory is specific to the application name but not the version.
@@ -630,15 +669,22 @@ public class Application {
 	 * @return temp directory
 	 */
 	public static File getUserTempDirectory() {
-		checkAppInitialized();
-		return app.layout.getUserTempDir();
+		try {
+			// 'app' will be null when the application has not been initialized yet.  In this case,
+			// we provide the default user temp directory.
+			return app != null ? app.layout.getUserTempDir()
+					: ApplicationUtilities.getDefaultUserTempDir("ghidra");
+		}
+		catch (IOException e) {
+			throw new AssertException(e);
+		}
 	}
 
 	/**
 	 * Returns the cache directory specific to the user and the application.
 	 * The intention is for directory contents to be preserved, however the
 	 * specific location is platform specific and contents may be removed when
-	 * not in use and may in fact be the same directory the user temp directory.
+	 * not in use.
 	 * This directory is specific to the application name but not the version.
 	 * Resources stored within this directory should utilize some
 	 * form of access locking and/or unique naming.
@@ -649,6 +695,24 @@ public class Application {
 		return app.layout.getUserCacheDir();
 	}
 
+	/**
+	 * Creates a new empty file in the Application's temp directory, using the given prefix and 
+	 * suffix strings to generate its name.  
+	 * 
+	 * @param prefix The prefix string to be used in generating the file's name; must be at least 
+	 *   three characters long
+	 * @param suffix The suffix string to be used in generating the file's name; may be 
+	 *   {@code null}, in which case the suffix {@code ".tmp"} will be used
+	 * @return A {@link File} denoting a newly-created empty file
+	 * @throws IllegalArgumentException If the {@code prefix} argument contains fewer than three 
+	 *   characters
+	 * @throws IOException If a file could not be created
+	 * @see File#createTempFile(String, String, File)
+	 */
+	public static File createTempFile(String prefix, String suffix) throws IOException {
+		return File.createTempFile(prefix, suffix, getUserTempDirectory());
+	}
+
 	/**
 	 * Returns a collection of all the module root directories. A module root directory is
 	 * the top-level directory of a module.
@@ -766,10 +830,11 @@ public class Application {
 	/**
 	 * Returns a collection of module library directories. Library directories are optional for a module.
 	 * @return a collection of module library directories.
+	 * @see ModuleUtilities#getModuleLibDirectories(Collection)
 	 */
 	public static Collection<ResourceFile> getLibraryDirectories() {
 		checkAppInitialized();
-		return ModuleUtilities.getModuleLibDirectories(app.layout.getModules());
+		return ModuleUtilities.getModuleLibDirectories(app.layout.getModules().values());
 	}
 
 	/**
@@ -852,7 +917,7 @@ public class Application {
 	}
 
 	/**
-	 * Return the directory relative the the name module's data directory. (i.e. "/data" will
+	 * Return the directory relative to the name module's data directory. (i.e. "/data" will
 	 * be prepended to the given path)
 	 * @param moduleName the name of the module.
 	 * @param relativePath the path relative to the module's data directory.
@@ -867,7 +932,7 @@ public class Application {
 	}
 
 	/**
-	 * Return the directory relative the the name module's directory.
+	 * Return the directory relative to the name module's directory.
 	 * @param moduleName the name of the module.
 	 * @param relativePath the path relative to the module's root directory.
 	 * @return the directory
