@@ -317,7 +317,7 @@ public class FrontEndPlugin extends Plugin
 					r.run();
 				}
 				else {
-					SwingUtilities.invokeLater(r);
+					Swing.runLater(r);
 				}
 			}
 		}
@@ -414,12 +414,12 @@ public class FrontEndPlugin extends Plugin
 
 	@Override
 	public void viewedProjectAdded(URL projectView) {
-		SwingUtilities.invokeLater(() -> rebuildRecentMenus());
+		Swing.runLater(() -> rebuildRecentMenus());
 	}
 
 	@Override
 	public void viewedProjectRemoved(URL projectView) {
-		SwingUtilities.invokeLater(() -> rebuildRecentMenus());
+		Swing.runLater(() -> rebuildRecentMenus());
 	}
 
 	/**
@@ -535,7 +535,7 @@ public class FrontEndPlugin extends Plugin
 	void selectFiles(final Set<DomainFile> files) {
 		// Do this later in case any of the given files are newly created, which means that the
 		// GUIs may have not yet been notified.
-		SwingUtilities.invokeLater(() -> {
+		Swing.runLater(() -> {
 			// there was a delete bug; make the set unmodifiable to catch this earlier
 			Set<DomainFile> unmodifiableFiles = Collections.unmodifiableSet(files);
 			if (dataTablePanel.isCapacityExceeded()) {
@@ -551,7 +551,7 @@ public class FrontEndPlugin extends Plugin
 	void selectFolder(final DomainFolder folder) {
 		// Do this later in case any of the given files are newly created, which means that the
 		// GUIs may have not yet been notified.
-		SwingUtilities.invokeLater(() -> {
+		Swing.runLater(() -> {
 			projectDataPanel.showTree();
 			dataTreePanel.selectDomainFolder(folder);
 		});
@@ -651,7 +651,7 @@ public class FrontEndPlugin extends Plugin
 			}
 		}
 		catch (Exception e) {
-			Msg.showError(this, null, "Error Exporting Tool", "Error exporting tool tool", e);
+			Msg.showError(this, null, "Error Exporting Tool", "Error exporting tool", e);
 		}
 	}
 
