@@ -22,7 +22,6 @@ import ghidra.program.model.listing.*;
 import ghidra.program.model.mem.Memory;
 import ghidra.program.model.symbol.*;
 import ghidra.util.task.TaskMonitor;
-import ghidra.util.task.TaskMonitorAdapter;
 
 /**
  * FollowFlow follows the program's code flow either forward or backward from an initial
@@ -34,7 +33,7 @@ import ghidra.util.task.TaskMonitorAdapter;
  */
 public class FollowFlow {
 	private Program program;
-	private AddressSet initialAddresses;
+	private AddressSetView initialAddresses;
 
 	private boolean followAllFlow = true;
 	private boolean followComputedCall = true;
@@ -47,6 +46,7 @@ public class FollowFlow {
 
 	private boolean followIntoFunction = true;
 	private boolean includeData = true;
+	private AddressSpace restrictedAddressSpace = null; // if set restrict flow to this space only
 	private Address nextSymbolAddr;
 
 	/**
@@ -69,7 +69,7 @@ public class FollowFlow {
 	 * <BR>FlowType.INDIRECTION
 	 *
 	 */
-	public FollowFlow(Program program, AddressSet addressSet, FlowType[] doNotFollow) {
+	public FollowFlow(Program program, AddressSetView addressSet, FlowType[] doNotFollow) {
 		this.program = program;
 		this.initialAddresses = addressSet;
 		updateFollowFlags(doNotFollow);
@@ -95,12 +95,12 @@ public class FollowFlow {
 	 * @param followIntoFunctions true if flows into (or back from) defined functions
 	 * should be followed.
 	 */
-	public FollowFlow(Program program, AddressSet addressSet, FlowType[] doNotFollow,
+	public FollowFlow(Program program, AddressSetView addressSet, FlowType[] doNotFollow,
 			boolean followIntoFunctions) {
 		this(program, addressSet, doNotFollow);
 		this.followIntoFunction = followIntoFunctions;
 	}
-	
+
 	/**
 	 * Constructor
 	 * 
@@ -126,35 +126,65 @@ public class FollowFlow {
 		this.includeData = includeData;
 	}
 
+	/**
+	 * Constructor
+	 * 
+	 * @param program the program whose flow we are following.
+	 * @param address the initial address that should be flowed from or flowed to.
+	 * @param doNotFollow array of flow types that are not to be followed.
+	 * @param restrictSingleAddressSpace if true collected flows should be restricted to
+	 * a single address space identified by {@code address}.
+	 * null or empty array indicates follow all flows. The following are valid
+	 * flow types for the doNotFollow array:
+	 * <BR>FlowType.COMPUTED_CALL
+	 * <BR>FlowType.CONDITIONAL_CALL
+	 * <BR>FlowType.UNCONDITIONAL_CALL
+	 * <BR>FlowType.COMPUTED_JUMP
+	 * <BR>FlowType.CONDITIONAL_JUMP
+	 * <BR>FlowType.UNCONDITIONAL_JUMP
+	 * <BR>FlowType.INDIRECTION
+	 * @param followIntoFunctions true if flows into (or back from) defined functions
+	 * should be followed.
+	 * @param includeData true if instruction flows into un-disassembled data should be included
+	 */
+	public FollowFlow(Program program, Address address, FlowType[] doNotFollow,
+			boolean followIntoFunctions, boolean includeData, boolean restrictSingleAddressSpace) {
+		this(program, new AddressSet(address, address), doNotFollow, followIntoFunctions);
+		if (restrictSingleAddressSpace) {
+			restrictedAddressSpace = address.getAddressSpace();
+		}
+		this.includeData = includeData;
+	}
+
 	/**
 	 * updateFollowFlags
 	 *
-	 * @param doNotFollow array of flow types that are not to be followed.
+	 * @param doNotFollowFlows array of flow types that are not to be followed.
 	 * null or empty array indicates follow all flows.
 	 */
-	private void updateFollowFlags(FlowType[] doNotFollow) {
-		if ((doNotFollow != null) && (doNotFollow.length > 0)) {
+	private void updateFollowFlags(FlowType[] doNotFollowFlows) {
+		if ((doNotFollowFlows != null) && (doNotFollowFlows.length > 0)) {
 			followAllFlow = false;
-			for (int index = 0; index < doNotFollow.length; index++) {
-				if (doNotFollow[index].equals(RefType.COMPUTED_CALL)) {
+			for (FlowType flowType : doNotFollowFlows) {
+				if (flowType.equals(RefType.COMPUTED_CALL)) {
 					followComputedCall = false;
 				}
-				else if (doNotFollow[index].equals(RefType.CONDITIONAL_CALL)) {
+				else if (flowType.equals(RefType.CONDITIONAL_CALL)) {
 					followConditionalCall = false;
 				}
-				else if (doNotFollow[index].equals(RefType.UNCONDITIONAL_CALL)) {
+				else if (flowType.equals(RefType.UNCONDITIONAL_CALL)) {
 					followUnconditionalCall = false;
 				}
-				else if (doNotFollow[index].equals(RefType.COMPUTED_JUMP)) {
+				else if (flowType.equals(RefType.COMPUTED_JUMP)) {
 					followComputedJump = false;
 				}
-				else if (doNotFollow[index].equals(RefType.CONDITIONAL_JUMP)) {
+				else if (flowType.equals(RefType.CONDITIONAL_JUMP)) {
 					followConditionalJump = false;
 				}
-				else if (doNotFollow[index].equals(RefType.UNCONDITIONAL_JUMP)) {
+				else if (flowType.equals(RefType.UNCONDITIONAL_JUMP)) {
 					followUnconditionalJump = false;
 				}
-				else if (doNotFollow[index].equals(RefType.INDIRECTION)) {
+				else if (flowType.equals(RefType.INDIRECTION)) {
 					followPointers = false;
 				}
 			}
@@ -170,8 +200,10 @@ public class FollowFlow {
 	 * @param startAddresses the initial addresses that should be flowed from or flowed to.
 	 * @param forward true to determine the flows "from" the startAddresses. false (backward) to 
 	 * determine flows "to" the startAddresses.
+	 * @return code unit flow represented by an address set as determined by the flow options.
+	 * An empty address set will be returned if cancelled.
 	 */
-	private AddressSet getAddressFlow(TaskMonitor monitor, AddressSet startAddresses,
+	private AddressSet getAddressFlow(TaskMonitor monitor, AddressSetView startAddresses,
 			boolean forward) {
 
 		if (monitor == null) {
@@ -233,7 +265,7 @@ public class FollowFlow {
 	 * @param forward true to determine the flows from the code unit. false to determine flows
 	 * to the code unit.
 	 */
-	private void getCodeUnitFlow(TaskMonitor monitor, AddressSet startAddresses,
+	private void getCodeUnitFlow(TaskMonitor monitor, AddressSetView startAddresses,
 			AddressSet flowAddressSet, CodeUnit codeUnit, boolean forward) {
 		if (codeUnit instanceof Data) {
 			getIndirectCodeFlow(monitor, startAddresses, flowAddressSet, (Data) codeUnit, forward);
@@ -256,7 +288,7 @@ public class FollowFlow {
 		}
 	}
 
-	private void getIndirectCodeFlow(TaskMonitor monitor, AddressSet startAddresses,
+	private void getIndirectCodeFlow(TaskMonitor monitor, AddressSetView startAddresses,
 			AddressSet flowAddressSet, Data data, boolean forward) {
 		// Follow data - isolate each primitive within startAddresses
 		if (!data.isDefined()) {
@@ -289,7 +321,7 @@ public class FollowFlow {
 	 * instruction code units.
 	 * @param monitor a cancellable task monitor
 	 * @param flowAddressSet the address set to be added to
-	 * @param currentCodeUnit the code unit to flow from.
+	 * @param codeUnit the code unit to flow from.
 	 *     Appropriate flows out of this code unit will be traversed.
 	 * @param dataAddr null or the address to flow from within the currentCodeUnit for Data.
 	 */
@@ -311,10 +343,15 @@ public class FollowFlow {
 		if (!followIntoFunction) {
 			try {
 				nextSymbolAddr = getNextSymbolAddress(start_addr.add(1), nextSymbolAddr);
-			} catch (AddressOutOfBoundsException e) {
+			}
+			catch (AddressOutOfBoundsException e) {
 				nextSymbolAddr = null;
 			}
 		}
+		
+		// Delay adding instructions in delay slots to the functions body
+		// until the end.  This allows for branches into the delay slot to be handled correctly.
+		AddressSet delaySlotSet = new AddressSet();
 
 		while (!monitor.isCancelled() && !instructionStack.isEmpty()) {
 
@@ -334,36 +371,25 @@ public class FollowFlow {
 			if (flowAddressSet.contains(currentAddress)) {
 				continue;
 			}
-
-			// If code unit is a delay-slot instruction, backup to delayed instruction     	
+  	
 			Instruction instr = currentInstr;
-//        	while (instr.isInDelaySlot()) {      		
-//        		Address fallFrom = instr.getFallFrom();
-//        		if (fallFrom == null) {
-//        			// assumes delay slot instructions have no flow
-//        			flowAddressSet.addRange(instr.getMinAddress(),
-//                                    currentInstr.getMaxAddress());
-//  					break;
-//        		}
-//        		instr = program.getListing().getInstructionContaining(fallFrom);	
-//        	}
-//        	if (instr.isInDelaySlot())
-//        		continue;  // unable to find non-delay-slot instruction
-//			currentInstr = instr;
 
-			// handle instruction - include associated delay slot instructions
+			// handle instruction with delay slot instructions
 			Address end = instr.getMaxAddress();
 			int delaySlotDepth = instr.getDelaySlotDepth();
 			for (int i = 0; i < delaySlotDepth; i++) {
 				instr = instr.getNext();
 				if (instr == null)
 					break;
-				end = instr.getMaxAddress();
+				delaySlotSet.add(instr.getMinAddress(),instr.getMaxAddress());
 			}
 			flowAddressSet.addRange(currentInstr.getMinAddress(), end);
 			followInstruction(instructionStack, flowAddressSet, currentInstr);
 
 		}
+		
+		// add in any instructions that were in a delayslot
+		flowAddressSet.add(delaySlotSet);
 	} // followCode
 
 	/**
@@ -424,7 +450,8 @@ public class FollowFlow {
 	 * @param flowAddressSet the address set to hold the entire flow.
 	 * @return the original instruction or the first instruction that is part of a delay slot.
 	 */
-	private Instruction getAdjustedInstruction(Instruction currentInstr, AddressSet flowAddressSet) {
+	private Instruction getAdjustedInstruction(Instruction currentInstr,
+			AddressSet flowAddressSet) {
 		Address currentAddress = currentInstr.getMinAddress();
 
 		// Return if code unit already encountered
@@ -476,7 +503,8 @@ public class FollowFlow {
 			if (symbols.hasNext()) {
 				Symbol symbol = symbols.next();
 				Address addr = symbol.getAddress();
-				if (addr.getAddressSpace().equals(curAddr.getAddressSpace()) && memory.contains(addr)) {
+				if (addr.getAddressSpace().equals(curAddr.getAddressSpace()) &&
+					memory.contains(addr)) {
 					return addr;
 				}
 			}
@@ -492,7 +520,7 @@ public class FollowFlow {
 	 * instruction code units.
 	 *
 	 * @param flowAddressSet the address set to add our addresses to.
-	 * @param currentCodeUnit the Instruction object to flow from.
+	 * @param currentInstr the Instruction object to flow from.
 	 *     Appropriate flows out of this code unit will be traversed.
 	 */
 	private void followInstruction(Stack<CodeUnit> instructionStack, AddressSet flowAddressSet,
@@ -506,7 +534,8 @@ public class FollowFlow {
 		Address[] flowAddresses = getFlowsFromInstruction(currentInstr);
 		for (int index = 0; (flowAddresses != null) && (index < flowAddresses.length); index++) {
 			nextAddress = flowAddresses[index];
-			if (nextAddress != null) {
+			if (nextAddress != null && (restrictedAddressSpace == null ||
+				restrictedAddressSpace == nextAddress.getAddressSpace())) {
 				CodeUnit nextCodeUnit = program.getListing().getCodeUnitContaining(nextAddress);
 				if (nextCodeUnit != null) {
 					if (nextCodeUnit instanceof Data && includeData) {
@@ -538,7 +567,8 @@ public class FollowFlow {
 			}
 		}
 
-		if (nextAddress != null) {
+		if (nextAddress != null && (restrictedAddressSpace == null ||
+			restrictedAddressSpace == nextAddress.getAddressSpace())) {
 			Instruction nextInstruction = program.getListing().getInstructionAt(nextAddress);
 			if (nextInstruction != null) {
 				instructionStack.push(nextInstruction);
@@ -575,7 +605,8 @@ public class FollowFlow {
 		 * Follow Flows Backward *
 		 *************************/
 		Address[] flowFromAddresses = getFlowsAndPointersToInstruction(currentInstr);
-		for (int index = 0; (flowFromAddresses != null) && (index < flowFromAddresses.length); index++) {
+		for (int index = 0; (flowFromAddresses != null) &&
+			(index < flowFromAddresses.length); index++) {
 			fromAddress = flowFromAddresses[index];
 			if (fromAddress != null) {
 				CodeUnit nextCodeUnit = program.getListing().getCodeUnitContaining(fromAddress);
@@ -632,9 +663,8 @@ public class FollowFlow {
 		do {
 			// check each delay slot instruction for flows into it.
 			try {
-				instruction =
-					listing.getInstructionContaining(instruction.getMinAddress().subtractNoWrap(
-						alignment));
+				instruction = listing.getInstructionContaining(
+					instruction.getMinAddress().subtractNoWrap(alignment));
 				if (instruction == null) {
 					break;
 				}
@@ -691,7 +721,8 @@ public class FollowFlow {
 				(currentFlowType.equals(RefType.CONDITIONAL_JUMP) && !followConditionalJump) ||
 				(currentFlowType.equals(RefType.UNCONDITIONAL_JUMP) && !followUnconditionalJump) ||
 				(currentFlowType.equals(RefType.CONDITIONAL_CALL) && !followConditionalCall) ||
-				(currentFlowType.equals(RefType.UNCONDITIONAL_CALL) && !followUnconditionalCall) || (currentFlowType.equals(RefType.INDIRECTION) && !followPointers))) {
+				(currentFlowType.equals(RefType.UNCONDITIONAL_CALL) && !followUnconditionalCall) ||
+				(currentFlowType.equals(RefType.INDIRECTION) && !followPointers))) {
 			shouldFollowFlow = false;
 		}
 		else {
@@ -705,7 +736,7 @@ public class FollowFlow {
 	 * matching the ones that should be followed will have the address it flows
 	 * to returned.
 	 * 
-	 * @param the instruction being flowed from.
+	 * @param instr the instruction being flowed from.
 	 * @return array of the addresses being flowed to in the manner we are
 	 * interested in.
 	 */
@@ -737,7 +768,7 @@ public class FollowFlow {
 	 * matching the ones that should be followed will have the address it flows
 	 * from returned.
 	 * 
-	 * @param the instruction being flowed to.
+	 * @param instr the instruction being flowed to.
 	 * @return array of the addresses that flow to the instruction in the manner we are
 	 * interested in.
 	 */
@@ -786,8 +817,9 @@ public class FollowFlow {
 	 * reference to an instruction. If the flow at the address isn't from a pointer to 
 	 * an instruction then just the address passed to this method is added to the flow set.
 	 *
+	 * @param instructionStack code unit stack for subsequent flow analysis
 	 * @param flowAddressSet the address set to add our addresses to.
-	 * @param currentCodeUnit the Data object to flow from.
+	 * @param data the Data object to flow from.
 	 *     Appropriate flows out of this code unit will be traversed.
 	 * @param addr the flow reference address which is contained within data.
 	 */
@@ -810,10 +842,10 @@ public class FollowFlow {
 				ReferenceManager referenceManager = program.getReferenceManager();
 				Reference[] memRefs = referenceManager.getReferencesFrom(addr);
 				boolean foundRef = false;
-				for (int i = 0; i < memRefs.length; i++) {
-					RefType rt = memRefs[i].getReferenceType();
+				for (Reference memRef : memRefs) {
+					RefType rt = memRef.getReferenceType();
 					if (rt.isData()) {
-						if (pushInstruction(instructionStack, memRefs[i].getToAddress())) {
+						if (pushInstruction(instructionStack, memRef.getToAddress())) {
 							foundRef = true; // pointer was to an instruction.
 						}
 					}
@@ -904,7 +936,8 @@ public class FollowFlow {
 	 * when the FollowFlow was constructed and the type of flow requested.
 	 * This method follows flows in the forward direction.
 	 * @param monitor a cancellable task monitor, may be null
-	 * @return the resulting address set.
+	 * @return code unit flow represented by an address set as determined by the flow options.
+	 * An empty address set will be returned if cancelled.
 	 */
 	public AddressSet getFlowAddressSet(TaskMonitor monitor) {
 		return getAddressFlow(monitor, initialAddresses, true);
@@ -918,11 +951,11 @@ public class FollowFlow {
 	 * backwards direction to determine the addresses that are flowing to those in the initial
 	 * set.
 	 * @param monitor a cancellable task monitor, may be null
-	 * @return the resulting address set.
+	 * @return code unit flow represented by an address set as determined by the flow options.
+	 * An empty address set will be returned if cancelled.
 	 */
 	public AddressSet getFlowToAddressSet(TaskMonitor monitor) {
 		return getAddressFlow(monitor, initialAddresses, false);
 	}
 
 } // end FollowFlow class
-
